vfbLib.parsers.text.OpenTypeStringParser
========================================

.. currentmodule:: vfbLib.parsers.text

.. autoclass:: OpenTypeStringParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OpenTypeStringParser.__init__
      ~OpenTypeStringParser.parse
      ~OpenTypeStringParser.parse_hex
      ~OpenTypeStringParser.read_double
      ~OpenTypeStringParser.read_doubles
      ~OpenTypeStringParser.read_float
      ~OpenTypeStringParser.read_floats
      ~OpenTypeStringParser.read_int16
      ~OpenTypeStringParser.read_int32
      ~OpenTypeStringParser.read_int8
      ~OpenTypeStringParser.read_str
      ~OpenTypeStringParser.read_str_all
      ~OpenTypeStringParser.read_uint16
      ~OpenTypeStringParser.read_uint32
      ~OpenTypeStringParser.read_uint8
      ~OpenTypeStringParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OpenTypeStringParser.encoding
      ~OpenTypeStringParser.master_count
      ~OpenTypeStringParser.stream
      ~OpenTypeStringParser.ttStemsH_count
      ~OpenTypeStringParser.ttStemsV_count
   
   